@@ -44,8 +44,7 @@ class Network:
     Furthermore, model settings and report parameter settings/precision settings are incorporated as well.
 
     Attributes:
-      title: Contains the networkx graph of the network
-      vertices: List of all Vertex objects in the network
+      title: Network name
       labels: List of all Labels in the network
       backdrop: Contains the Backdrop object of the network
       energies: List of all Energy curves in the network
@@ -79,9 +78,9 @@ class Network:
 
     _nodes: SuperComponentRegistry = field(default_factory=NodeRegistry)
     _links: SuperComponentRegistry = field(default_factory=LinkRegistry)
-    _curves: dict[str, Curve] = field(default_factory=ComponentRegistry)
-    _patterns: dict[str, Pattern] = field(default_factory=ComponentRegistry)
-    _rules: dict[str, Rule] = field(default_factory=ComponentRegistry)
+    _curves: ComponentRegistry = field(default_factory=ComponentRegistry)
+    _patterns: ComponentRegistry = field(default_factory=ComponentRegistry)
+    _rules: ComponentRegistry = field(default_factory=ComponentRegistry)
 
     @classmethod
     def read(cls, filename=Optional[str], content=Optional[str]):
