@@ -3,9 +3,15 @@ from typing import TYPE_CHECKING
 import logging
 
 from oopnet.writer.module_reader import list_section_writer_callables
-from oopnet.writer.writing_modules import write_system_operation, write_network_map_tags, write_water_quality, \
-    write_options_and_reporting, write_network_components
+from oopnet.writer.writing_modules import (
+    write_system_operation,
+    write_network_map_tags,
+    write_water_quality,
+    write_options_and_reporting,
+    write_network_components,
+)
 from oopnet.utils.oopnet_logging import logging_decorator
+
 if TYPE_CHECKING:
     from oopnet.elements.network import Network
 
@@ -24,15 +30,20 @@ def write(network: Network, filename: str) -> int:
       0 if successful
 
     """
-    logger.info(f'Writing network to {filename!r}')
+    logger.info(f"Writing network to {filename!r}")
 
-    modules = [write_network_components, write_network_map_tags, write_options_and_reporting,
-               write_system_operation, write_water_quality]
+    modules = [
+        write_network_components,
+        write_network_map_tags,
+        write_options_and_reporting,
+        write_system_operation,
+        write_water_quality,
+    ]
 
     all_functions = list_section_writer_callables(modules)
 
     newlist = sorted(all_functions, key=lambda x: x.priority)
-    with open(filename, 'w') as fid:
+    with open(filename, "w") as fid:
         for f in newlist:
             f.writerfunction(network, fid)
 
